# Reference

## Color Vision Deficiency Friendly Colormaps (`cmweather.cm_colorblind`)

```{eval-rst}
.. automodule:: cmweather.cm_colorblind
    :members:
    :undoc-members:
    :show-inheritance:
```

## More Weather Colormaps (`cmweather.cm`)

```{eval-rst}
.. automodule:: cmweather.cm
    :members:
    :undoc-members:
    :show-inheritance:
```
